@@ -8,6 +8,7 @@ use Mojo::IOLoop;
 use Mojo::IOLoop::Stream;
 
 has [qw/error exit_status pid stream/];
+has arguments => sub { [] };
 
 has exe => 'phantomjs';
 
@@ -24,7 +25,9 @@ sub kill {
 sub start {
   my ($self, $file) = @_;
 
-  my $pid = open my $pipe, '-|', $self->exe, "$file";
+  my @command = ($self->exe, @{ $self->arguments }, "$file");
+  warn 'Spawning: ' . (join ', ', map { "'$_'" } @command) . "\n" if DEBUG;
+  my $pid = open my $pipe, '-|', @command;
   die 'Could not spawn' unless defined $pid;
   $self->pid($pid);
   $self->emit(spawn => $pid);
@@ -88,6 +91,13 @@ Passed the new child pid.
 
 =head1 ATTRIBUTES
 
+=head2 arguments
+
+Holds an array reference of arguments passed directly to the PhantomJS executable when it is run.
+
+  my @phantom_args = ('--proxy=127.0.0.1:8080', '--proxy-type='socks5');
+  my $proc = Mojo::Phantom::Process->new(arguments => \@phantom_args);
+
 =head2 error
 
 Holds errors caught from the L</stream>'s error event.
